@@ -2,9 +2,8 @@ package AnyEvent::Filesys::Notify::Role::FSEvents;
 
 # ABSTRACT: Use Mac::FSEvents to watch for changed files
 
-use Moo::Role;
-use MooX::late;
-use namespace::sweep;
+use Moose::Role;
+use namespace::autoclean;
 use AnyEvent;
 use Mac::FSEvents;
 use Carp;
@@ -17,21 +16,21 @@ sub _init {
     my @fs_monitors =
       map { Mac::FSEvents->new( { path => $_, latency => $self->interval, } ) }
       @{ $self->dirs };
+    $self->_fs_monitor( \@fs_monitors );
 
     # Create an AnyEvent->io watcher for each fs_monitor
-    my @watchers;
-    for my $fs_monitor (@fs_monitors) {
+    # Done in a block so we can scope and preserve the $fs_monitor
+    my @watchers =
+      map {                     ## no critic (ProhibitComplexMappings)
+        my $fs_monitor = $_;    # needed to scope $fs_monitor
+        AnyEvent->io(
+            fh   => $fs_monitor->watch,
+            poll => 'r',
+            cb   => sub {
+                $self->_process_events( $fs_monitor->read_events() );
+            } )
+      } @fs_monitors;
 
-        my $w = AE::io $fs_monitor->watch, 0, sub {
-            if ( my @events = $fs_monitor->read_events ) {
-                $self->_process_events(@events);
-            }
-        };
-        push @watchers, $w;
-
-    }
-
-    $self->_fs_monitor( \@fs_monitors );
     $self->_watcher( \@watchers );
     return 1;
 }
@@ -48,7 +47,7 @@ AnyEvent::Filesys::Notify::Role::FSEvents - Use Mac::FSEvents to watch for chang
 
 =head1 VERSION
 
-version 0.23_10
+version 0.17
 
 =head1 AUTHOR
 
