@@ -2,9 +2,8 @@ package AnyEvent::Filesys::Notify::Role::Inotify2;
 
 # ABSTRACT: Use Linux::Inotify2 to watch for changed files
 
-use Moo::Role;
-use MooX::late;
-use namespace::sweep;
+use Moose::Role;
+use namespace::autoclean;
 use AnyEvent;
 use Linux::Inotify2;
 use Carp;
@@ -78,7 +77,7 @@ AnyEvent::Filesys::Notify::Role::Inotify2 - Use Linux::Inotify2 to watch for cha
 
 =head1 VERSION
 
-version 0.23_10
+version 0.17
 
 =head1 AUTHOR
 
